package com.tzld.crawler.etl;

import com.aliyun.mq.http.MQClient;
import com.aliyun.mq.http.MQProducer;
import com.aliyun.mq.http.model.TopicMessage;
import com.google.common.collect.Lists;
import com.huaban.analysis.jieba.JiebaSegmenter;
import com.huaban.analysis.jieba.SegToken;
import com.tzld.crawler.etl.mq.EtlMQConsumer;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.IntStream;

@SpringBootTest
class EtlServerApplicationTests {
    @Value("${rocketmq.accessKey}")
    private String accessKey;
    @Value("${rocketmq.secretKey}")
    private String secretKey;
    @Value("${rocketmq.httpEndpoint}")
    private String httpEndpoint;
    @Value("${rocketmq.instanceId}")
    private String instanceId;

    /**
     * 排除 EtlMQConsumer 的加载
     */
    @MockBean
    private EtlMQConsumer etlMQConsumer;


    @Test
    void produceMsgTest() {
        MQClient mqClient = new MQClient(httpEndpoint, accessKey, secretKey);
        MQProducer producer = mqClient.getProducer(instanceId, "topic_crawler_etl_dev");
        ArrayList<String> platforms = Lists.newArrayList("benshanzhufu", "kuaishou", "douyin", "xigua", "gongzhonghao", "xiaoniangao");

        IntStream.range(0, 20).forEach(x -> {
            try {
                String s = "{\"user_id\": 6281907,\"out_user_id\": \"53322270\",\"platform\": \"" + platforms.get(x % 6) + "\",\"strategy\": \"author\"," +
                        "\"out_video_id\": \"" + System.currentTimeMillis() + "\"," +
                        "\"video_title\": \"" + x + "人最佳喧，睡眠时间⚡\",\"cover_url\": \"https://cdn-xphoto2.xiaoniangao.cn/5071472172@690w_385h_0e_1pr%7C690x385-5rc_0r.jpg?OSSAccessKeyId=LTAI4G2W1FsgwzAWYpPoB3v6&Expires=1688140805&Signature=BC%2F9U%2BTjPGVwaqTpStSO1kdYhQU%3D\"," +
                        "\"video_url\": \"https://cdn-xalbum2.xiaoniangao.cn/64858d720000014567e794c9?Expires=1704038400&OSSAccessKeyId=LTAI5tB7cRkYiqHcTdkVprwb&Signature=j0WjPwp6wq1XnstwpXL6z7f9wRM%3D\"" +
                        ",\"duration\": 40,\"publish_time\": \"2023-06-08 23:01:47\",\"play_cnt\": 602,\"like_cnt\": 0,\"share_cnt\": 0,\"collection_cnt\": 0,\"comment_cnt\": 0,\"crawler_rule\": {\"period\": { \"max\": 3, \"min\": 3 },\"duration\": { \"max\": 999999999999999, \"min\": 40 },\"play_cnt\": { \"max\": 999999999999999, \"min\": 500 }},\"width\": 450,\"height\": 254}";

                TopicMessage pubMsg = new TopicMessage(s.getBytes());
                producer.publishMessage(pubMsg);
            } catch (Exception e) {
                System.out.println(e);
            }
        });

    }


    @Test
    public void testDemo() {
        JiebaSegmenter segmenter = new JiebaSegmenter();
        List<SegToken> process = segmenter.process("这是一个伸手不见五指的黑夜。我叫孙悟空，我爱北京，我爱Java和Rust还有Golang。", JiebaSegmenter.SegMode.SEARCH);
        for (SegToken segToken : process) {
            System.out.println(segToken.word);
        }
    }

}
